@@ -28,4 +28,7 @@ class Basics:
                 self.value = value
             else:
                 self.value /= value
-        return self.value
\ No newline at end of file
+        return self.value
+
+def main():
+    return Basics
